==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/FieldDetails.java <==
package com.example.model;

/**
 * Model for FieldDetails
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "FieldDetails", description = "Model for FieldDetails")
@javax.xml.bind.annotation.XmlRootElement(name = "FieldDetails")
public class FieldDetails implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String birthDate = null;
	private java.lang.String birthDay = null;
	private java.lang.String birthMonth = null;
	private java.lang.String birthYear = null;
	private java.lang.String cardType = null;
	private java.lang.String countryOfIssue = null;
	private java.lang.String expiryDay = null;
	private java.lang.String familyName = null;
	private java.lang.String givenName = null;
	private java.lang.String immiCardNumber = null;
	private java.lang.String licenceNumber = null;
	private java.lang.String middleName = null;
	private java.lang.String registrationState = null;
	private java.lang.String stateOfIssue = null;
	
	/**
	 */
	public FieldDetails birthDate(java.lang.String birthDate) {
		setBirthDate(birthDate);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("BirthDate")
	@javax.validation.constraints.NotNull
	public java.lang.String getBirthDate() {
		return this.birthDate;
	}
	public void setBirthDate(java.lang.String birthDate) {
		this.birthDate = birthDate;
	}
	
	/**
	 */
	public FieldDetails birthDay(java.lang.String birthDay) {
		setBirthDay(birthDay);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("BirthDay")
	public java.lang.String getBirthDay() {
		return this.birthDay;
	}
	public void setBirthDay(java.lang.String birthDay) {
		this.birthDay = birthDay;
	}
	
	/**
	 */
	public FieldDetails birthMonth(java.lang.String birthMonth) {
		setBirthMonth(birthMonth);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("BirthMonth")
	public java.lang.String getBirthMonth() {
		return this.birthMonth;
	}
	public void setBirthMonth(java.lang.String birthMonth) {
		this.birthMonth = birthMonth;
	}
	
	/**
	 */
	public FieldDetails birthYear(java.lang.String birthYear) {
		setBirthYear(birthYear);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("BirthYear")
	public java.lang.String getBirthYear() {
		return this.birthYear;
	}
	public void setBirthYear(java.lang.String birthYear) {
		this.birthYear = birthYear;
	}
	
	/**
	 */
	public FieldDetails cardType(java.lang.String cardType) {
		setCardType(cardType);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("CardType")
	public java.lang.String getCardType() {
		return this.cardType;
	}
	public void setCardType(java.lang.String cardType) {
		this.cardType = cardType;
	}
	
	/**
	 */
	public FieldDetails countryOfIssue(java.lang.String countryOfIssue) {
		setCountryOfIssue(countryOfIssue);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("CountryOfIssue")
	public java.lang.String getCountryOfIssue() {
		return this.countryOfIssue;
	}
	public void setCountryOfIssue(java.lang.String countryOfIssue) {
		this.countryOfIssue = countryOfIssue;
	}
	
	/**
	 */
	public FieldDetails expiryDay(java.lang.String expiryDay) {
		setExpiryDay(expiryDay);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("ExpiryDay")
	public java.lang.String getExpiryDay() {
		return this.expiryDay;
	}
	public void setExpiryDay(java.lang.String expiryDay) {
		this.expiryDay = expiryDay;
	}
	
	/**
	 */
	public FieldDetails familyName(java.lang.String familyName) {
		setFamilyName(familyName);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("FamilyName")
	public java.lang.String getFamilyName() {
		return this.familyName;
	}
	public void setFamilyName(java.lang.String familyName) {
		this.familyName = familyName;
	}
	
	/**
	 */
	public FieldDetails givenName(java.lang.String givenName) {
		setGivenName(givenName);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("GivenName")
	public java.lang.String getGivenName() {
		return this.givenName;
	}
	public void setGivenName(java.lang.String givenName) {
		this.givenName = givenName;
	}
	
	/**
	 */
	public FieldDetails immiCardNumber(java.lang.String immiCardNumber) {
		setImmiCardNumber(immiCardNumber);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("ImmiCardNumber")
	public java.lang.String getImmiCardNumber() {
		return this.immiCardNumber;
	}
	public void setImmiCardNumber(java.lang.String immiCardNumber) {
		this.immiCardNumber = immiCardNumber;
	}
	
	/**
	 */
	public FieldDetails licenceNumber(java.lang.String licenceNumber) {
		setLicenceNumber(licenceNumber);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("LicenceNumber")
	public java.lang.String getLicenceNumber() {
		return this.licenceNumber;
	}
	public void setLicenceNumber(java.lang.String licenceNumber) {
		this.licenceNumber = licenceNumber;
	}
	
	/**
	 */
	public FieldDetails middleName(java.lang.String middleName) {
		setMiddleName(middleName);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("MiddleName")
	public java.lang.String getMiddleName() {
		return this.middleName;
	}
	public void setMiddleName(java.lang.String middleName) {
		this.middleName = middleName;
	}
	
	/**
	 */
	public FieldDetails registrationState(java.lang.String registrationState) {
		setRegistrationState(registrationState);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("RegistrationState")
	public java.lang.String getRegistrationState() {
		return this.registrationState;
	}
	public void setRegistrationState(java.lang.String registrationState) {
		this.registrationState = registrationState;
	}
	
	/**
	 */
	public FieldDetails stateOfIssue(java.lang.String stateOfIssue) {
		setStateOfIssue(stateOfIssue);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("StateOfIssue")
	public java.lang.String getStateOfIssue() {
		return this.stateOfIssue;
	}
	public void setStateOfIssue(java.lang.String stateOfIssue) {
		this.stateOfIssue = stateOfIssue;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		FieldDetails fieldDetails = (FieldDetails) o;
		return java.util.Objects.equals(this.birthDate, fieldDetails.birthDate)
				&& java.util.Objects.equals(this.birthDay, fieldDetails.birthDay)
				&& java.util.Objects.equals(this.birthMonth, fieldDetails.birthMonth)
				&& java.util.Objects.equals(this.birthYear, fieldDetails.birthYear)
				&& java.util.Objects.equals(this.cardType, fieldDetails.cardType)
				&& java.util.Objects.equals(this.countryOfIssue, fieldDetails.countryOfIssue)
				&& java.util.Objects.equals(this.expiryDay, fieldDetails.expiryDay)
				&& java.util.Objects.equals(this.familyName, fieldDetails.familyName)
				&& java.util.Objects.equals(this.givenName, fieldDetails.givenName)
				&& java.util.Objects.equals(this.immiCardNumber, fieldDetails.immiCardNumber)
				&& java.util.Objects.equals(this.licenceNumber, fieldDetails.licenceNumber)
				&& java.util.Objects.equals(this.middleName, fieldDetails.middleName)
				&& java.util.Objects.equals(this.registrationState, fieldDetails.registrationState)
				&& java.util.Objects.equals(this.stateOfIssue, fieldDetails.stateOfIssue);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.birthDate, this.birthDay, this.birthMonth, this.birthYear, this.cardType, this.countryOfIssue, this.expiryDay, this.familyName, this.givenName, this.immiCardNumber, this.licenceNumber, this.middleName, this.registrationState, this.stateOfIssue);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class FieldDetails {\n");
		
		sb.append("    birthDate: ").append(toIndentedString(this.birthDate)).append("\n");
		sb.append("    birthDay: ").append(toIndentedString(this.birthDay)).append("\n");
		sb.append("    birthMonth: ").append(toIndentedString(this.birthMonth)).append("\n");
		sb.append("    birthYear: ").append(toIndentedString(this.birthYear)).append("\n");
		sb.append("    cardType: ").append(toIndentedString(this.cardType)).append("\n");
		sb.append("    countryOfIssue: ").append(toIndentedString(this.countryOfIssue)).append("\n");
		sb.append("    expiryDay: ").append(toIndentedString(this.expiryDay)).append("\n");
		sb.append("    familyName: ").append(toIndentedString(this.familyName)).append("\n");
		sb.append("    givenName: ").append(toIndentedString(this.givenName)).append("\n");
		sb.append("    immiCardNumber: ").append(toIndentedString(this.immiCardNumber)).append("\n");
		sb.append("    licenceNumber: ").append(toIndentedString(this.licenceNumber)).append("\n");
		sb.append("    middleName: ").append(toIndentedString(this.middleName)).append("\n");
		sb.append("    registrationState: ").append(toIndentedString(this.registrationState)).append("\n");
		sb.append("    stateOfIssue: ").append(toIndentedString(this.stateOfIssue)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/FieldDetails.java <==
package com.example.model;

/**
 * Model for FieldDetails
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "FieldDetails", description = "Model for FieldDetails")
@javax.xml.bind.annotation.XmlRootElement(name = "FieldDetails")
public class FieldDetails implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String birthDate = null;
	private java.lang.String birthDay = null;
	private java.lang.String birthMonth = null;
	private java.lang.String birthYear = null;
	private java.lang.String cardType = null;
	private java.lang.String countryOfIssue = null;
	private java.lang.String expiryDay = null;
	private java.lang.String familyName = null;
	private java.lang.String givenName = null;
	private java.lang.String immiCardNumber = null;
	private java.lang.String licenceNumber = null;
	private java.lang.String middleName = null;
	private java.lang.String registrationState = null;
	private java.lang.String stateOfIssue = null;
	
	/**
	 */
	public FieldDetails birthDate(java.lang.String birthDate) {
		setBirthDate(birthDate);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "BirthDate")
	@com.fasterxml.jackson.annotation.JsonProperty("BirthDate")
	@javax.validation.constraints.NotNull
	public java.lang.String getBirthDate() {
		return this.birthDate;
	}
	public void setBirthDate(java.lang.String birthDate) {
		this.birthDate = birthDate;
	}
	
	/**
	 */
	public FieldDetails birthDay(java.lang.String birthDay) {
		setBirthDay(birthDay);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "BirthDay")
	@com.fasterxml.jackson.annotation.JsonProperty("BirthDay")
	public java.lang.String getBirthDay() {
		return this.birthDay;
	}
	public void setBirthDay(java.lang.String birthDay) {
		this.birthDay = birthDay;
	}
	
	/**
	 */
	public FieldDetails birthMonth(java.lang.String birthMonth) {
		setBirthMonth(birthMonth);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "BirthMonth")
	@com.fasterxml.jackson.annotation.JsonProperty("BirthMonth")
	public java.lang.String getBirthMonth() {
		return this.birthMonth;
	}
	public void setBirthMonth(java.lang.String birthMonth) {
		this.birthMonth = birthMonth;
	}
	
	/**
	 */
	public FieldDetails birthYear(java.lang.String birthYear) {
		setBirthYear(birthYear);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "BirthYear")
	@com.fasterxml.jackson.annotation.JsonProperty("BirthYear")
	public java.lang.String getBirthYear() {
		return this.birthYear;
	}
	public void setBirthYear(java.lang.String birthYear) {
		this.birthYear = birthYear;
	}
	
	/**
	 */
	public FieldDetails cardType(java.lang.String cardType) {
		setCardType(cardType);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "CardType")
	@com.fasterxml.jackson.annotation.JsonProperty("CardType")
	public java.lang.String getCardType() {
		return this.cardType;
	}
	public void setCardType(java.lang.String cardType) {
		this.cardType = cardType;
	}
	
	/**
	 */
	public FieldDetails countryOfIssue(java.lang.String countryOfIssue) {
		setCountryOfIssue(countryOfIssue);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "CountryOfIssue")
	@com.fasterxml.jackson.annotation.JsonProperty("CountryOfIssue")
	public java.lang.String getCountryOfIssue() {
		return this.countryOfIssue;
	}
	public void setCountryOfIssue(java.lang.String countryOfIssue) {
		this.countryOfIssue = countryOfIssue;
	}
	
	/**
	 */
	public FieldDetails expiryDay(java.lang.String expiryDay) {
		setExpiryDay(expiryDay);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "ExpiryDay")
	@com.fasterxml.jackson.annotation.JsonProperty("ExpiryDay")
	public java.lang.String getExpiryDay() {
		return this.expiryDay;
	}
	public void setExpiryDay(java.lang.String expiryDay) {
		this.expiryDay = expiryDay;
	}
	
	/**
	 */
	public FieldDetails familyName(java.lang.String familyName) {
		setFamilyName(familyName);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "FamilyName")
	@com.fasterxml.jackson.annotation.JsonProperty("FamilyName")
	public java.lang.String getFamilyName() {
		return this.familyName;
	}
	public void setFamilyName(java.lang.String familyName) {
		this.familyName = familyName;
	}
	
	/**
	 */
	public FieldDetails givenName(java.lang.String givenName) {
		setGivenName(givenName);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "GivenName")
	@com.fasterxml.jackson.annotation.JsonProperty("GivenName")
	public java.lang.String getGivenName() {
		return this.givenName;
	}
	public void setGivenName(java.lang.String givenName) {
		this.givenName = givenName;
	}
	
	/**
	 */
	public FieldDetails immiCardNumber(java.lang.String immiCardNumber) {
		setImmiCardNumber(immiCardNumber);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "ImmiCardNumber")
	@com.fasterxml.jackson.annotation.JsonProperty("ImmiCardNumber")
	public java.lang.String getImmiCardNumber() {
		return this.immiCardNumber;
	}
	public void setImmiCardNumber(java.lang.String immiCardNumber) {
		this.immiCardNumber = immiCardNumber;
	}
	
	/**
	 */
	public FieldDetails licenceNumber(java.lang.String licenceNumber) {
		setLicenceNumber(licenceNumber);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "LicenceNumber")
	@com.fasterxml.jackson.annotation.JsonProperty("LicenceNumber")
	public java.lang.String getLicenceNumber() {
		return this.licenceNumber;
	}
	public void setLicenceNumber(java.lang.String licenceNumber) {
		this.licenceNumber = licenceNumber;
	}
	
	/**
	 */
	public FieldDetails middleName(java.lang.String middleName) {
		setMiddleName(middleName);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "MiddleName")
	@com.fasterxml.jackson.annotation.JsonProperty("MiddleName")
	public java.lang.String getMiddleName() {
		return this.middleName;
	}
	public void setMiddleName(java.lang.String middleName) {
		this.middleName = middleName;
	}
	
	/**
	 */
	public FieldDetails registrationState(java.lang.String registrationState) {
		setRegistrationState(registrationState);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "RegistrationState")
	@com.fasterxml.jackson.annotation.JsonProperty("RegistrationState")
	public java.lang.String getRegistrationState() {
		return this.registrationState;
	}
	public void setRegistrationState(java.lang.String registrationState) {
		this.registrationState = registrationState;
	}
	
	/**
	 */
	public FieldDetails stateOfIssue(java.lang.String stateOfIssue) {
		setStateOfIssue(stateOfIssue);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "StateOfIssue")
	@com.fasterxml.jackson.annotation.JsonProperty("StateOfIssue")
	public java.lang.String getStateOfIssue() {
		return this.stateOfIssue;
	}
	public void setStateOfIssue(java.lang.String stateOfIssue) {
		this.stateOfIssue = stateOfIssue;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		FieldDetails fieldDetails = (FieldDetails) o;
		return java.util.Objects.equals(this.birthDate, fieldDetails.birthDate)
				&& java.util.Objects.equals(this.birthDay, fieldDetails.birthDay)
				&& java.util.Objects.equals(this.birthMonth, fieldDetails.birthMonth)
				&& java.util.Objects.equals(this.birthYear, fieldDetails.birthYear)
				&& java.util.Objects.equals(this.cardType, fieldDetails.cardType)
				&& java.util.Objects.equals(this.countryOfIssue, fieldDetails.countryOfIssue)
				&& java.util.Objects.equals(this.expiryDay, fieldDetails.expiryDay)
				&& java.util.Objects.equals(this.familyName, fieldDetails.familyName)
				&& java.util.Objects.equals(this.givenName, fieldDetails.givenName)
				&& java.util.Objects.equals(this.immiCardNumber, fieldDetails.immiCardNumber)
				&& java.util.Objects.equals(this.licenceNumber, fieldDetails.licenceNumber)
				&& java.util.Objects.equals(this.middleName, fieldDetails.middleName)
				&& java.util.Objects.equals(this.registrationState, fieldDetails.registrationState)
				&& java.util.Objects.equals(this.stateOfIssue, fieldDetails.stateOfIssue);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.birthDate, this.birthDay, this.birthMonth, this.birthYear, this.cardType, this.countryOfIssue, this.expiryDay, this.familyName, this.givenName, this.immiCardNumber, this.licenceNumber, this.middleName, this.registrationState, this.stateOfIssue);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class FieldDetails {\n");
		
		sb.append("    birthDate: ").append(toIndentedString(this.birthDate)).append("\n");
		sb.append("    birthDay: ").append(toIndentedString(this.birthDay)).append("\n");
		sb.append("    birthMonth: ").append(toIndentedString(this.birthMonth)).append("\n");
		sb.append("    birthYear: ").append(toIndentedString(this.birthYear)).append("\n");
		sb.append("    cardType: ").append(toIndentedString(this.cardType)).append("\n");
		sb.append("    countryOfIssue: ").append(toIndentedString(this.countryOfIssue)).append("\n");
		sb.append("    expiryDay: ").append(toIndentedString(this.expiryDay)).append("\n");
		sb.append("    familyName: ").append(toIndentedString(this.familyName)).append("\n");
		sb.append("    givenName: ").append(toIndentedString(this.givenName)).append("\n");
		sb.append("    immiCardNumber: ").append(toIndentedString(this.immiCardNumber)).append("\n");
		sb.append("    licenceNumber: ").append(toIndentedString(this.licenceNumber)).append("\n");
		sb.append("    middleName: ").append(toIndentedString(this.middleName)).append("\n");
		sb.append("    registrationState: ").append(toIndentedString(this.registrationState)).append("\n");
		sb.append("    stateOfIssue: ").append(toIndentedString(this.stateOfIssue)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
